library(vegan)
library(rioja)
library(ggplot2)
library(ggrepel)
speraw<-read.csv(file.choose(),row.names=1)
speform<-decostand(speraw, method = "hellinger") #Transform data
rawNMDS <-metaMDS(speraw, distance ="bray", k=3, maxit=400000) #Perform NMDS
NMDS  <-metaMDS(speform, distance ="bray", k=3, maxit =400000)


spedist=dist(speform)
speclust=chclust(spedist, method = "coniss") #Cluster
bstick(speclust) # Validate groups


#Chrysophytes
{
  data.scores<-as.data.frame(scores(NMDS)) #scores to data frame
  data.scores$Site<-rownames(data.scores)
  data.scores$Zone<-c(rep("Post-Transitional", 12), rep("Anthro-Transitionary 2", 9),rep("Anthro-Transitionary 1", 17), rep("Pre-Transitional", 23)) #Set Zones
  
  
  species.scores <- as.data.frame(scores(rawNMDS, "species"))  #Scores to a data frame
  species.scores$species <- rownames(species.scores)  # Species Column
  
  head(species.scores)  
  head(data.scores)  #Confirm additions
  
  ggplot() + 
    theme_bw() +
    ggtitle("Chrysophyte NMDS") +
    geom_text_repel(data=species.scores,aes(x=NMDS1,y=NMDS2,label=species), size = 8, max.overlaps = 20) +  # add the species labels
    geom_point(data=data.scores,aes(x=NMDS1,y=NMDS2,shape=Zone,colour=Zone),size=5, alpha = 0.6) + 
    scale_shape_manual(values = c(15,16,17,18)) +# add the point markers
    xlim(-1,0.5) +
    theme(plot.title = element_text(hjust = 0.5, size = 20), axis.text = element_text(size = 14), axis.title= element_text(size = 16), legend.text = element_text(size=18), legend.title = element_text(size=18))
  
}

#Diatoms
{
  data.scores<-as.data.frame(scores(rawNMDS))
  data.scores$site<-rownames(data.scores)
  data.scores$Zone<-c(rep("Post-Transitional", 12), rep("Anthro-Transitionary", 27), rep("Pre-Transitional", 10))
  head(data.scores)
  
  species.scores <- as.data.frame(scores(rawNMDS, "species"))  
  species.scores$species <- rownames(species.scores)  
  head(species.scores)  #look at the data
  
  
  ggplot() + 
    theme_bw() +
    ggtitle("Diatom NMDS") +
    geom_text_repel(data=species.scores,aes(x=NMDS1,y=NMDS2,label=species), size = 8, max.overlaps = 20) +  # add the species labels
    geom_point(data=data.scores,aes(x=NMDS1,y=NMDS2,shape=Zone,colour=Zone),size=5, alpha = 0.6) + 
    scale_shape_manual(values = c(15,16,17)) 
    xlim(-1,1.2) +
    theme(plot.title = element_text(hjust = 0.5, size = 20), axis.text = element_text(size = 14), axis.title= element_text(size = 16), legend.text = element_text(size=18), legend.title = element_text(size=18))
  
}